# SPDX-FileCopyrightText: Huawei Inc.
#
# SPDX-License-Identifier: MIT

HOMEPAGE = "https://docs.lvgl.io/latest/en/html/porting/index.html"
SUMMARY = "LVGL's Display and Touch pad drivers"
DESCRIPTION = "Collection of drivers: SDL, framebuffer, wayland and more..."
LICENSE = "MIT"
LIC_FILES_CHKSUM = "file://LICENSE;md5=d6fc0df890c5270ef045981b516bb8f2"

SRC_URI = "git://github.com/lvgl/lv_drivers;protocol=https;branch=release/v8.3"
SRCREV = "71830257710f430b6d8d1c324f89f2eab52488f1"

DEPENDS = "lvgl"

inherit cmake

S = "${WORKDIR}/git"

PACKAGECONFIG[drm] = ",,libdrm"
PACKAGECONFIG[evdev] = ",,"
PACKAGECONFIG[fbdev] = ",,"
PACKAGECONFIG[libinput] = ",,libinput"
PACKAGECONFIG[sdl] = ",,virtual/libsdl2"
PACKAGECONFIG[wayland] = ",,libxkbcommon wayland"

PACKAGECONFIG ?= "drm evdev fbdev ${@bb.utils.contains('DISTRO_FEATURES', 'wayland', 'libinput wayland', '', d)}"

EXTRA_OECMAKE += "-Dinstall:BOOL=ON -DLIB_INSTALL_DIR=${baselib} -DBUILD_SHARED_LIBS=ON"

TARGET_CFLAGS += "-DLV_CONF_INCLUDE_SIMPLE=1"
TARGET_CFLAGS += "-I${RECIPE_SYSROOT}/${includedir}/lvgl"
TARGET_CFLAGS += "${@bb.utils.contains('PACKAGECONFIG','drm','-I${RECIPE_SYSROOT}/${includedir}/libdrm','',d)}"

# Upstream does not support a default configuration
# but propose a default "disabled" template, which is used as reference
# More configuration can be done using external configuration variables
do_configure:append() {
    [ -r "${S}/lv_drv_conf.h" ] && return

    sed -e "s|#if 0 .*Set it to \"1\" to enable the content.*|#if 1 // Enabled by ${PN}|g" \
        < "${S}/lv_drv_conf_template.h" > "${S}/lv_drv_conf.h"

    if ${@bb.utils.contains('PACKAGECONFIG', 'wayland', 'true', 'false', d)}; then
        sed -i "s|#  define USE_WAYLAND       0|#  define USE_WAYLAND       1|g" "${S}/lv_drv_conf.h"
    fi
    if ${@bb.utils.contains('PACKAGECONFIG', 'fbdev', 'true', 'false', d)}; then
        sed -i "s|#  define USE_FBDEV           0|#  define USE_FBDEV           1|g" "${S}/lv_drv_conf.h"
    fi
    if ${@bb.utils.contains('PACKAGECONFIG', 'drm', 'true', 'false', d)}; then
        sed -i "s|#  define USE_DRM           0|#  define USE_DRM           1|g" "${S}/lv_drv_conf.h"
    fi
    if ${@bb.utils.contains('PACKAGECONFIG', 'libinput', 'true', 'false', d)}; then
        sed -i "s|#  define USE_LIBINPUT           0|#  define USE_LIBINPUT           1|g" "${S}/lv_drv_conf.h"
    fi
    if ${@bb.utils.contains('PACKAGECONFIG', 'evdev', 'true', 'false', d)}; then
        sed -i "s|#  define USE_EVDEV           0|#  define USE_EVDEV           1|g" "${S}/lv_drv_conf.h"
    fi
}

FILES_SOLIBSDEV = ""

FILES:${PN} += "\
    ${libdir}/liblv_drivers.so \
    "

FILES:${PN}-dev += "\
    ${includedir}/lvgl/lv_drivers/ \
    "
