# SPDX-FileCopyrightText: Huawei Inc.
#
# SPDX-License-Identifier: MIT

HOMEPAGE = "https://lvgl.io/"
DESCRIPTION = "LVGL is an OSS graphics library to create embedded GUI"
SUMMARY = "Light and Versatile Graphics Library"
LICENSE = "MIT"
LIC_FILES_CHKSUM = "file://LICENCE.txt;md5=bf1198c89ae87f043108cea62460b03a"

SRC_URI = "git://github.com/lvgl/lvgl;protocol=https;branch=release/v8.3"
SRCREV = "9ec3b8706b098f60940cee6ac211d3cb3141aedf"

SRC_URI:append = " \
    file://cmake_examples_demos.patch \
    file://lv_linux_tick_get.patch \
"

inherit cmake

EXTRA_OECMAKE = "-DLIB_INSTALL_DIR=${baselib} -DBUILD_SHARED_LIBS=ON"
S = "${WORKDIR}/git"

LVGL_CONFIG_LV_MEM_CUSTOM ?= "0"
LVGL_CONFIG_LV_COLOR_DEPTH ?= "32"

# Upstream does not support a default configuration
# but propose a default "disabled" template, which is used as reference
# More configuration can be done using external configuration variables
do_configure:prepend() {
    [ -r "${S}/lv_conf.h" ] \
        || sed -e 's|#if 0 .*Set it to "1" to enable .*|#if 1 // Enabled|g' \
	    -e "s|\(#define LV_COLOR_DEPTH \).*|\1 ${LVGL_CONFIG_LV_COLOR_DEPTH}|g" \
	    \
	    -e "s|\(#define LV_MEM_CUSTOM .*\)0|\1${LVGL_CONFIG_LV_MEM_CUSTOM}|g" \
	    \
	    -e "s|\(#define LV_TICK_CUSTOM \).*|\1 1|g" \
	    -e "s|\(#define LV_TICK_CUSTOM_INCLUDE \).*|\1 <time.h>|g" \
	    -e "s|\(#define LV_TICK_CUSTOM_SYS_TIME_EXPR \).*|lv_linux_tick_get()|g" \
	    \
            < "${S}/lv_conf_template.h" > "${S}/lv_conf.h"
}

do_install:append() {
    install -m 0755 ${WORKDIR}/build/*.so ${D}${libdir}
}

PACKAGES =+ "${PN}-demos ${PN}-demos-dev ${PN}-examples ${PN}-examples-dev"

FILES_SOLIBSDEV = ""

FILES:${PN} += "\
    ${libdir}/liblvgl.so \
    "

FILES:${PN}-demos += "\
    ${libdir}/liblvgl_demos.so \
    "
RDEPENDS:${PN}-demos += "${PN}"

FILES:${PN}-examples += "\
    ${libdir}/liblvgl_examples.so \
    "
RDEPENDS:${PN}-examples += "${PN}"

FILES:${PN}-dev += "\
    ${includedir}/${PN}/*.h \
    ${includedir}/${PN}/src \
    "

FILES:${PN}-demos-dev += "\
    ${includedir}/${PN}/demos \
    "
RDEPENDS:${PN}-demos-dev += "${PN}-demos ${PN}-dev"

FILES:${PN}-examples-dev += "\
    ${includedir}/${PN}/examples \
    "
RDEPENDS:${PN}-examples-dev += "${PN}-examples ${PN}-dev"
